@@ -5,9 +5,8 @@ import threading
 from forecastio.models import Forecast
 
 
-def load_forecast(key, inLat, inLong, time=None, units="auto", lazy=False,
+def load_forecast(key, lat, lng, time=None, units="auto", lazy=False,
                   callback=None):
-
     """
         This function builds the request url and loads some or all of the
         needed json depending on lazy is True
@@ -23,10 +22,6 @@ def load_forecast(key, inLat, inLong, time=None, units="auto", lazy=False,
                 probably a faster response time (I haven't checked)
     """
 
-    lat = inLat
-    lng = inLong
-    time = time
-
     if time is None:
         url = 'https://api.forecast.io/forecast/%s/%s,%s' \
               '?units=%s' % (key, lat, lng, units,)
@@ -43,21 +38,31 @@ def load_forecast(key, inLat, inLong, time=None, units="auto", lazy=False,
     else:
         baseURL = url
 
+    return manual(baseURL, callback=callback)
+
+
+def manual(requestURL, callback=None):
+    """
+        This fuction is used by load_forecast OR by users to manually
+        construct the URL for an API call.
+    """
+
     if callback is None:
-        return make_forecast(make_request(baseURL))
+        return get_forecast(requestURL)
     else:
-        thr = threading.Thread(target=load_async, args=(baseURL,),
-                               kwargs={'callback': callback})
-        thr.start()
+        thread = threading.Thread(target=load_async,
+                                  args=(requestURL, callback))
+        thread.start()
 
 
-def make_forecast(response):
-    return Forecast(response.json(), response, response.headers)
+def get_forecast(requestURL):
+    forecastio_reponse = requests.get(requestURL)
 
+    json = forecastio_reponse.json()
+    headers = forecastio_reponse.headers
 
-def make_request(url):
-    return requests.get(url)
+    return Forecast(json, forecastio_reponse, headers)
 
 
 def load_async(url, callback):
-    callback(make_forecast(make_request(url)))
+    callback(get_forecast(url))
